@@ -2,7 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::fasta;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::fasta::AUTHORITY = 'cpan:SCHWIGON';
 }
-# ABSTRACT: benchmark plugin - Shootout::fasta - Language shootout plugin: fasta
+# ABSTRACT: benchmark - Generate and write random DNA sequences
 
 # COMMAND LINE:
 # /usr/bin/perl fasta.perl-4.perl 25000000
@@ -178,7 +178,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::fasta - benchmark plugin - Shootout::fasta - Language shootout plugin: fasta
+Benchmark::Perl::Formance::Plugin::Shootout::fasta - benchmark - Generate and write random DNA sequences
 
 =head1 CONFIGURATION
 
@@ -186,10 +186,10 @@ Because the "fasta" plugin's output can be used to feed other
 benchmarks that work on "fasta" data you control its output
 via defines:
 
-   $ perl-formance --plugins=Shootout::fast \
-                    -DShootout_fasta_n=1000 \
-                    -DShootout_fasta_print=1 \
-                    -DShootout_fasta_count=1
+   $ benchmark-perlformance --plugins=Shootout::fasta \
+                             -DShootout_fasta_n=1000 \
+                             -DShootout_fasta_print=1 \
+                             -DShootout_fasta_count=1
 
 where C<_n> is the algorithm's parameter, C<_print=1>
 means print out the result and C<_count> is the repetition
