@@ -2,7 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::revcomp;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::revcomp::AUTHORITY = 'cpan:SCHWIGON';
 }
-# ABSTRACT: benchmark plugin - Shootout::revcomp - Language shootout plugin: revcomp
+# ABSTRACT: benchmark - Read DNA sequences - write their reverse-complement
 
 # COMMAND LINE:
 # /usr/bin/perl revcomp.perl-4.perl 0 < revcomp-input25000000.txt
@@ -93,15 +93,15 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::revcomp - benchmark plugin - Shootout::revcomp - Language shootout plugin: revcomp
+Benchmark::Perl::Formance::Plugin::Shootout::revcomp - benchmark - Read DNA sequences - write their reverse-complement
 
 =head1 CONFIGURATION
 
 You can control whether to output the result in case you want to reuse
 it:
 
-   $ perl-formance --plugins=Shootout::revcomp \
-                    -DShootout_revcomp_print=1
+   $ benchmark-perlformance --plugins=Shootout::revcomp \
+                             -DShootout_revcomp_print=1
 
 =head1 AUTHOR
 
