@@ -96,7 +96,7 @@ Benchmark::Perl::Formance::Plugin::Threads - benchmark plugin - Threads - Stress
 Run it as any other plugin. You can define how many threads should
 maximally be started. Default is 100.
 
-  $ perl-formance --plugins=Threads -DThreads_threadcount=64
+  $ benchmark-perlformance --plugins=Threads -DThreads_threadcount=64
 
 =head1 BUGS
 
