@@ -108,7 +108,7 @@ Benchmark::Perl::Formance::Plugin::ThreadsShared - benchmark plugin - ThreadsSha
 Run it as any other plugin. You can define how many threads should
 maximally be started. Default is 100.
 
-  $ perl-formance --plugins=ThreadsShared -DThreads_threadcount=64
+  $ benchmark-perlformance --plugins=ThreadsShared -DThreads_threadcount=64
 
 =head1 BUGS
 
